package com.ruoyi.project.patrol.dev.mapper;

import com.ruoyi.project.patrol.dev.domain.TDevPostFire;

import java.util.List;

/**
 * 地上消火栓检查记录Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-30
 */
public interface TDevPostFireMapper
{
    /**
     * 查询地上消火栓检查记录
     *
     * @param id 地上消火栓检查记录主键
     * @return 地上消火栓检查记录
     */
    public TDevPostFire selectTDevPostFireById(Long id);

    /**
     * 查询地上消火栓检查记录列表
     *
     * @param tDevPostFire 地上消火栓检查记录
     * @return 地上消火栓检查记录集合
     */
    public List<TDevPostFire> selectTDevPostFireList(TDevPostFire tDevPostFire);

    /**
     * 新增地上消火栓检查记录
     *
     * @param tDevPostFire 地上消火栓检查记录
     * @return 结果
     */
    public int insertTDevPostFire(TDevPostFire tDevPostFire);

    /**
     * 修改地上消火栓检查记录
     *
     * @param tDevPostFire 地上消火栓检查记录
     * @return 结果
     */
    public int updateTDevPostFire(TDevPostFire tDevPostFire);

    /**
     * 删除地上消火栓检查记录
     *
     * @param id 地上消火栓检查记录主键
     * @return 结果
     */
    public int deleteTDevPostFireById(Long id);

    /**
     * 批量删除地上消火栓检查记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTDevPostFireByIds(Long[] ids);
}
